@@ -88,6 +88,29 @@ my %template = (
 	right  => [ "+" , "|" ],
 	bottom =>   "-",
     },
+    c_box => {
+	top          =>   '*',
+	left         => [ '/**',
+			  '/* ' ],
+	center       => [ '**/ /**',
+			  ' */ /* ' ],
+	right        => [ '**/',
+			  ' */' ],
+	bottom       =>   '*',
+    },
+    c_box_2 => {
+	top          =>   '*',
+	left         => [ '/**',
+			  ' * ',
+			  ' **' ],
+	center       => [ '**  /**',
+			  ' *   * ',
+			  '**/  **' ],
+	right        => [ '** ',
+			  ' * ',
+			  '**/' ],
+	bottom       =>   '*',
+    },
     box => {
 	top    =>     "─",
 	left   => [  "┌─"  ,
